[![CI](https://github.com/monarch-initiative/genophenocorr/workflows/CI/badge.svg)](https://github.com/monarch-initiative/pyphetools/actions/workflows/python_ci.yml)

# pyphetools
Python Phenopacket Tools

This package currently is designed to test how to use the Python version of the phenopackets package together with pandas to create phenopackets from typical supplemental tables.

Development goals include making builder code similar to the Java package to create valid phenopackets and to perform JSON Schema-based validation.


## Documentation

See the tutorial and detailed documentation [here](https://monarch-initiative.github.io/pyphetools).

## PyPI

We have made the package available in the Python Package Index (pypi) at [pyphetools](https://pypi.org/project/pyphetools/).

